"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
exports.__esModule = true;
exports.loadTsconfig = exports.loadAliasConfigs = void 0;
var micromatch_1 = __importDefault(require("micromatch"));
var path_1 = require("path");
var tsconfig_paths_1 = require("tsconfig-paths");
function loadTsconfig(eslintConfigPath, aliasConfigPath, codeFilePath) {
    var config;
    try {
        if (aliasConfigPath) {
            if ((0, path_1.isAbsolute)(aliasConfigPath)) {
                config = (0, tsconfig_paths_1.loadConfig)(aliasConfigPath);
            }
            else {
                config = (0, tsconfig_paths_1.loadConfig)((0, path_1.join)(eslintConfigPath, aliasConfigPath));
            }
        }
        else {
            config = (0, tsconfig_paths_1.loadConfig)((0, path_1.dirname)(codeFilePath));
        }
    }
    catch (error) {
        if (error instanceof SyntaxError) {
            throw new Error("SyntaxError in TSConfig/JSConfig: ".concat(error.message));
        }
        throw error;
    }
    if (config.resultType !== "success") {
        throw new Error("validate tsconfig or jsconfig provided and ensure compilerOptions.baseUrl is set: ".concat(config.message));
    }
    return config;
}
exports.loadTsconfig = loadTsconfig;
function loadAliasConfigs(config, projectBaseDir) {
    return Object.entries(config.paths).reduce(function (configs, _a) {
        var aliasGlob = _a[0], aliasPaths = _a[1];
        aliasPaths.forEach(function (aliasPath) {
            var relativePathBase = micromatch_1["default"].scan(aliasPath).base;
            configs.push({
                alias: micromatch_1["default"].scan(aliasGlob).base,
                path: {
                    absolute: (0, path_1.join)(projectBaseDir, relativePathBase)
                }
            });
        });
        return configs;
    }, []);
}
exports.loadAliasConfigs = loadAliasConfigs;
